==> genai_protocol-1.0.8.tar.gz: genai_protocol-1.0.8/setup.py <==
from setuptools import setup, find_packages

setup(
    name="genai-protocol",
    version="1.0.8",
    description="A universal agents connector library that integrates with GenAI.works infrastructure",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Yaroslav Oliinyk, Valentyn Slivko, Ivan Kuzlo, Pavlo Shyrinskykh",
    author_email="yaroslav.oliinyk@chisw.com, valentyn.slivko@chisw.com, ivan.kuzlo@chisw.com, pavlo.shyrinskykh@genai.works",
    url="https://github.com/genai-works-org/genai-protocol",
    readme="README.md",
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    license="Apache License 2.0",
    install_requires=[
        "aiohappyeyeballs>=2.6.1",
        "aiohttp>=3.11.16",
        "aiosignal>=1.3.2",
        "annotated-types>=0.7.0",
        "attrs>=25.3.0",
        "frozenlist>=1.5.0",
        "idna>=3.10",
        "multidict>=6.2.0",
        "propcache>=0.3.1",
        "pydantic>=2.11.1",
        "pydantic-core>=2.33.0",
        "typing-extensions>=4.13.0",
        "typing-inspection>=0.4.0",
        "websockets>=15.0.1",
        "yarl>=1.18.3",
        "pyjwt>=2.10.1",
    ],
    extras_require={
        "dev": ["twine>=6.1.0"],
    },
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",
)

==> genai_protocol-1.0.9.tar.gz: genai_protocol-1.0.9/setup.py <==
from setuptools import setup, find_packages

setup(
    name="genai-protocol",
    version="1.0.9",
    description="A universal agents connector library that integrates with GenAI.works infrastructure",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Yaroslav Oliinyk, Valentyn Slivko, Ivan Kuzlo, Pavlo Shyrinskykh",
    author_email="pavlo.shyrinskykh@genai.works",
    url="https://github.com/genai-works-org/genai-protocol",
    readme="README.md",
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    license="Apache License 2.0",
    install_requires=[
        "aiohappyeyeballs>=2.6.1",
        "aiohttp>=3.11.16",
        "aiosignal>=1.3.2",
        "annotated-types>=0.7.0",
        "attrs>=25.3.0",
        "frozenlist>=1.5.0",
        "idna>=3.10",
        "multidict>=6.2.0",
        "propcache>=0.3.1",
        "pydantic>=2.11.1",
        "pydantic-core>=2.33.0",
        "typing-extensions>=4.13.0",
        "typing-inspection>=0.4.0",
        "websockets>=15.0.1",
        "yarl>=1.18.3",
        "pyjwt>=2.10.1",
    ],
    extras_require={
        "dev": ["twine>=6.1.0"],
    },
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",
)
